var system = require("../../../system");
const http = require("http");
const querystring = require('querystring');
var settings = require("../../../../config/settings");
const CtlBase = require("../../ctl.base");
const moment = require('moment');
const appconfig = system.getSysConfig();
class DeliverybillCtl extends CtlBase {
  constructor() {
    super("bizchance", CtlBase.getServiceName(DeliverybillCtl));
    this.materialService = system.getObject("service.bizchance.materialSve");
    this.receiveUrl = "http://192.168.1.140:4011/api/receive/entService/springBoard";
  }

  /*根据用户id获取商机信息，分页获取*/
  async findAndCountAll(pobj, qobj, req) {
    try {
      //TODO 根据业务员id获取该业务员所有交付单列表
      const rs = await this.service.findAndCountAll(pobj);
      let rarr = [];
      let results = rs.results.rows;
      results.forEach(element => {
        let robj = {};
        robj.id = element.id;//数据的id
        robj.deliverNumber = element.delivery_code;//交付单编号
        robj.businessName = element.product_name;//产品名称
        robj.businessType = element.product_code;//产品编码
        robj.sourceName = element.source_name;//渠道来源
        robj.source_name = element.source_name;//渠道来源
        robj.channelNumber = element.source_number;//渠道编码
        robj.facilitator_name = element.facilitator_name;
        robj.serviceName = element.facilitator_name;
        robj.baseInfo = element.delivery_info;//交付单详情
        robj.payStatus = element.delivery_info.payStatus;//交付状态
        robj.costPrice = element.cost_price;//成本
        robj.settleStatus=element.settle_status;
        if (robj.businessName == '公司注册'){
          if (robj.baseInfo.isWhether == "是" || robj.baseInfo.isVirtual == "是"){//如果有刻章需求或者是虚拟地址
            robj.relatedProducts = '有';
          }
          else{
            robj.relatedProducts = '无';
          }
        }
        else if (robj.businessName == '云上园区注册'){
          robj.registeredType = element.delivery_info.registeredType;//园区注册时，根据该值跳界面
          if (robj.baseInfo.isWhether == "是"){//如果有刻章需求或者是虚拟地址
            robj.relatedProducts = '有';
          }
          else{
            robj.relatedProducts = '无';
          }
        }
        else{
          robj.relatedProducts = '无';
        };
        robj.payAmount = element.selling_price;//交付单金额
        robj.deliverStatus = element.delivery_status;//交付单状态
        robj.contactsName = robj.baseInfo.contactsName;//联系人
        robj.contactsPhone = robj.baseInfo.contactsPhone;//联系电话
        robj.createdTime = this.timeFormat(element.created_at);//交付单创建时间
        rarr.push(robj);
      });
      rs.results.rows = rarr;
      return system.getResult(rs);
    } catch (error) {
      return system.getResultError(error);
    }
  }

  /*根据交付单编号获取交付单详情和材料详情*/
  async DealInfo(pobj,qobj,req){
    if (pobj.deliverNumber && pobj.deliverNumber != 'undefined')
    {
      try{
        var rs = await this.service.findInfoByDeliverCode(pobj);
        var ms = await this.materialService.findInfoByDeliverNumber(pobj);
        var rarr = {}
        if (rs){
          rarr.id =  rs.id;//数据的id
          rarr.baseInfo.deliverNumber = rs.deliver_code;//交付单编号
          rarr.baseInfo.businessName = rs.product_name;//产品名称
          rarr.baseInfo.businessType = rs.product_code;//产品编码
          rarr.baseInfo.channelSource = rs.source_name;//渠道名称
          rarr.baseInfo.channelNumber = rs.source_number;//渠道编码
          rarr.baseInfo.serviceCode = rs.service_address;//服务地区编码
          rarr.baseInfo.servicerCode = rs.facilitator_id;//服务商编码
          rarr.baseInfo.servicerName = rs.facilitator_name;//服务商名称
          rarr.baseInfo.clerkName = rs.salesman_name;//业务员名称
          rarr.baseInfo.clerkPhone = rs.salesman_phone;//业务员电话
          rarr.baseInfo.sellingPrice = rs.selling_price;//价格
          rarr.baseInfo.costPrice = rs.cost_price;//成本价
          if (rarr.businessName == "云上园区注册"){
            rarr.baseInfo.serviceArea = appconfig.pdict.registeredParkDict[rarr.serviceCode];//服务地区名称
          }
          else{
            rarr.baseInfo.serviceArea = appconfig.pdict.registeredAreaDict[rarr.serviceCode];//服务地区名称
          }
          rarr.deliveryInfo =  rs.delivery_info;//交付单详情
          rarr.contactsInfo.contactsName = rs.delivery_info.contactsName;//联系人信息
          rarr.contactsInfo.contactsPhone = rs.delivery_info.contactsPhone;//联系电话信息
          rarr.statusInfo.deliverStatus = rs.delivery_status;//状态
          rarr.statusInfo.statusReason = rs.close_reason;//状态原因
          rarr.companyInfo = ms.company_info;//公司详情
          rarr.registeredInfo = ms.registered_info;//注册信息
          rarr.contributionInfo = ms.contribution_info;//出资比例信息
          rarr.positionInfo = ms.position_info;//任职信息；公司注册和个人独资时取该值
          rarr.managerInfo = ms.position_info;//经营者信息，个体工商户的经营者信息取该值
          rarr.regInfo = ms.file_info;//注册文件信息
          rarr.expressInfo = ms.express_info;//邮寄信息
        }
        return system.getResult(rarr);
      }
      catch(error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误！");
    }
  }

  /*根据交付单编号更新交付单状态*/
  async updateStatusByDeliverCode(pobj,qobj,req){
    if (pobj.deliverNumber && pobj.deliverNumber != 'undefined' && pobj.deliverStatus && pobj.deliverStatus != 'undefined'){
      try{
        var res = await this.service.updateInfoByDeliverCode(pobj);
        //调商城接口，回传状态信息，放队列

        return system.getResult("更新成功！");
      }
      catch (error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误!");
    }
  }

  async UpdateofficialSealByDeliverCode(pobj,qobj,req){//更新营业执照扫描件和公章扫描件
    if ((pobj.deliverNumber && pobj.deliverNumber != 'undefined' && ((pobj.baseInfo.officialSeal && pobj.baseInfo.officialSeal != 'undefined') || (pobj.baseInfo.businessLicense && pobj.baseInfo.businessLicense != 'undefined')))){
     try{
      var rs = await this.service.findInfoByDeliverCode(pobj)//先得到交付单详情
      if (pobj.baseInfo.officialSeal && pobj.baseInfo.officialSeal != 'undefined'){
        rs.delivery_info.officialSeal = pobj.baseInfo.officialSeal;
      }
      if (pobj.baseInfo.businessLicense && pobj.baseInfo.businessLicense != 'undefined'){
        rs.delivery_info.businessLicense = pobj.baseInfo.businessLicense;
      }
       //更新详情
      var uarr = {
        "deliverNumber":pobj.deliverNumber,
        "baseInfo":rs.delivery_info
      };
      await this.service.updateInfoByDeliverCode(uarr);
      //回传信息给庄冰，放队列
      return system.getResult("更新成功");
     }
     catch(error){
      return system.getResultError(error);
     }
    }
    else{
      return system.getResultError("参数错误！");
    }
  }

  async updateExpressInfoByDeliverCode(pobj,qobj,req){//更新邮寄信息
    if (pobj.deliverNumber && pobj.deliverNumber != 'undefined' && pobj.expressInfo && pobj.expressInfo != 'undefined'){
      try{
        await this.materialService.updateInfoByDeliverNumber(pobj);
        //回传庄冰，放队列
        return system.getResult("更新成功");
      }
      catch{
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误！");
    }
  }

  /*根据交付单编号更新交付单详情*/
  async updateInfoByDeliverCode(pobj,qobj,req){//
    if (pobj.deliverNumber && pobj.deliverNumber != 'undefined'){
      try{
         //更新详情
        await this.service.updateInfoByDeliverCode(pobj);
        //更新材料信息
        await this.materialService.updateInfoByDeliverNumber(pobj);
        var statusInfo = {
          "deliverNumber":pobj.deliverNumber,
          "deliverStatus":"collecting"//状态为收集工商注册材料
        };
        //更新状态
        await this.service.updateStatusByDeliverCode(statusInfo);
        return system.getResult("操作成功！");
        //传给庄冰，放队列
        // pobj.baseInfo = deliveryInfo;
        // var rc = system.getObject("util.execClient");
        // var requrl = this.receiveUrl;
        // var params =  {
        //   "actionType":"updateOrderStatus",
        //   "actionBody":{
        //     "orderNum": pobj.deliverNumber,//订单编码
        //     "status":appconfig.pdict.ddyDict["collecting"],
        //     "deliverContent":pobj
        //   }
        // }   
        // var rtn = await rc.execPost(params, requrl);
        // var j = JSON.parse(rtn.stdout);
        // if (j.status == 1){
        //   return system.getResult("操作成功！");
        // }
        // else{
        //   return system.getResultError("更新交付单状态出错！");
        // }
      }
      catch(error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误！");
    }

  }

  async settleApply(p,q,req){
      let ids=p.ids
      let rtn=await this.service.settleApply(ids,req.userid,req.username)
      return system.getResult({})
  }
  /*根据商机编号插入交付单信息*/
  async insertInfo(pobj,qobj,req){//队列的时候用
    if (pobj.businessMode && pobj.businessMode != 'undefined' && pobj.schemeNumber && pobj.schemeNumber != 'undefined' 
      && pobj.deliverNumber && pobj.deliverNumber != 'undefined'){
      try{
        //更新状态给庄冰
        var rc = system.getObject("util.execClient");
        var requrl = this.receiveUrl;
        var params =  {
          "actionType":"updateOrderStatus",
          "actionBody":{
            "orderNum": pobj.businessMode,//订单编码
            "status":20,//已接单
            "deliverContent":pobj
          }
        }   
        var rtn = await rc.execPost(params, requrl);
        var j = JSON.parse(rtn.stdout);
        if (j.status  == 1){
          var res = await this.service.insertInfo(pobj);
          return system.getResult("插入成功！");
        }
        else{
          return system.getResultError("插入数据失败！");
        }

      }
      catch (error){
        return system.getResultError(error);
      }
    }else{
      return system.getResultError("参数错误!");
    }
  }

  timeFormat(date) {
    let localTime = moment.utc(date).toDate();
    localTime = moment(localTime).format("YYYY-MM-DD");
    return localTime;
  }
}
module.exports = DeliverybillCtl;

// var task = new DeliverybillCtl();
// var obj={"deliverNumber":"1111115","baseInfo":"","deliverInfo":{"isVirtual": "否", "isWhether": "是", "payStatus": "已交付", "contactsName": "张三", "contactsPhone": "13800138000"},"companyInfo":{"isWhether": "no", "addressType": "practical", "fullAddress": "gsgsgsgsgsg", "taxpayerType": "smallScaleTaxpayer", "businessScope": "sgsgsdgsdgd", "engagedIndustry": "culturalMedia", "companyProperties": "limitedLiabilityCompany"},
//           "registeredInfo":{"registeredCapital":"500","registeredDate":"20","reserveProportion":"15"},"contributionInfo":{"contribution_info":[{"shareholderName":"王五","contributionAmount":"200","contributionProportion":"40","IdentificationNumber":"1111111","phoneNumber":"1111111","contactAddress":"北京"},
//           {"shareholderName":"王六","contributionAmount":"200","contributionProportion":"40","IdentificationNumber":"1111111","phoneNumber":"1111111","contactAddress":"北京"},
//           {"shareholderName":"王七","contributionAmount":"100","contributionProportion":"20","IdentificationNumber":"1111111","phoneNumber":"1111111","contactAddress":"北京"}]}};
// task.updateInfoByDeliverCode(obj,{},{}).then(d=>{
//   console.log(d);
//   //console.log(d[0].analyse);

// })
